EncodeError

Enum EncodeError 

pub enum EncodeError {
    BufferFull,
}

Variants



BufferFull

wire_buf did not have room for the encoded bytes (1 for plain, up to 2 for an escape sequence). The caller should advance no cursors and treat the encode as failed.